


# TODO

- [X] tigr81 commands refactoring
- [X] scaffold react
- [X] add linter formatter ecc script from templates
- [] input: framework - prime react or mui  
- [] MUI template
- [X] prime react template
- [X] fastapi better
- [X] OK -> add __main__
- [X] OK -> pydantic settings
- [] ruff and dev deps
- [] - script/commands to run in project lifecycle
- [] fastapi auth provider: api key, oauth,..
- [] config modules pydantic
- [] model config commons config camel case
- [] lifespan
- [] logging as json

- [] fastapi: Dockerfile
- [X] python templates: ruff + code linting setup
- [] monorepo: add just dependency
- [] monorepo: delete dependencies already present when add

- [] add also copier template generator

## New Templates in road map

- [] typer cli template
- [] Google Cloud Funtion python pkg
- [] Azure Function python pkg
- [] full stack: chatbot template RAG opensource
- [] fastapi with sqlalchemy templates
- [] full stack: react + fastapi + sqlalchemy